@@ -35,6 +35,7 @@
     [RFC] https://www.ietf.org/rfc/rfc5389.txt
     [RFC] https://www.ietf.org/rfc/rfc3489.txt
 """
+
 from typing import Optional
 
 from udp.data import UInt16Data, UInt32Data
@@ -388,7 +389,7 @@ class XorMappedAddressValue(MappedAddressValue):
             array[a_pos] ^= factor[f_pos]
             a_pos -= 1
             f_pos += 1
-        return array
+        return bytes(array)
 
     @classmethod
     def new(cls, ip: str, port: int, family: int=None, factor: bytes=None):
@@ -457,7 +458,7 @@ class XorMappedAddressValue2(MappedAddressValue):
             array[a_pos] ^= factor[f_pos]
             a_pos += 1
             f_pos += 1
-        return array
+        return bytes(array)
 
     @classmethod
     def new(cls, ip: str, port: int, family: int=None, factor: bytes=None):
