@@ -34,6 +34,7 @@
 
 """
 
+import socket
 import time
 from abc import ABC, abstractmethod
 from typing import Union
@@ -87,8 +88,8 @@ class Node(ABC):
         """
         self.source_address: (str, int) = None
 
-    @staticmethod
-    def info(msg: str):
+    # noinspection PyMethodMayBeStatic
+    def info(self, msg: str):
         time_array = time.localtime(int(time.time()))
         time_string = time.strftime('%y-%m-%d %H:%M:%S', time_array)
         print('[%s] %s' % (time_string, msg))
@@ -514,3 +515,14 @@ class Client(Node, ABC):
             return NatType.PortRestrictedNAT, res11
         else:
             return NatType.RestrictedNAT, res3
+
+    @classmethod
+    def get_local_ip(cls, remote_host: str='8.8.8.8', remote_port: int=80) -> Optional[str]:
+        try:
+            sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
+            sock.connect((remote_host, remote_port))
+            ip = sock.getsockname()[0]
+        finally:
+            # noinspection PyUnboundLocalVariable
+            sock.close()
+        return ip
